"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var datatable_1 = require("primeng/components/datatable/datatable");
var moment = require("moment");
var base_filter_1 = require("../shared/base.filter");
/**
 * Clase base de los componentes TableView
 */
var BaseTableViewComponent = /** @class */ (function () {
    function BaseTableViewComponent(domainCachedService, tableViewService) {
        var _this = this;
        this.totalItems = 0;
        this.onPageChange = new core_1.EventEmitter();
        this.csvSeparator = ",";
        this.RESULTADOS_PAGE = base_filter_1.BaseFilter.RESULTADOS_PAGE; // se hace visible esta variable a cualquier subclase de tableview que pudiera necesitarla
        this.domainCachedService = domainCachedService;
        this.tableViewService = tableViewService;
        this.subscriptionMessages = tableViewService.observableExport.subscribe(function (message) {
            _this.exportCSV();
        });
    }
    BaseTableViewComponent.prototype.exportCSV = function () {
        var _this = this;
        var dt = this.dataTable;
        if (dt == null) {
            alert("Exportació no disponible");
            return;
        }
        var data = this.items;
        var csv = "";
        //headers
        for (var i = 0; i < dt.columns.length; i++) {
            if (dt.columns[i].field && !dt.columns[i].hidden) {
                csv += dt.columns[i].header || dt.columns[i].field;
                if (i < dt.columns.length - 1) {
                    csv += this.csvSeparator;
                }
            }
        }
        //body
        dt.value.forEach(function (record, i) {
            csv += "\n";
            for (var i_1 = 0; i_1 < dt.columns.length; i_1++) {
                if (dt.columns[i_1].field && !dt.columns[i_1].hidden) {
                    var cell = _this.getColumna(record, dt.columns[i_1].field) || dt.resolveFieldData(record, dt.columns[i_1].field);
                    if (cell == null) {
                        cell = "";
                    }
                    cell = cell.toString();
                    if (cell.indexOf(",") != -1) {
                        cell = '"' + cell + '"';
                    }
                    csv += cell;
                    if (i_1 < dt.columns.length - 1) {
                        csv += _this.csvSeparator;
                    }
                }
            }
        });
        var blob = new Blob(["\ufeff", csv], {
            type: "text/csv;charset=utf-8;"
        });
        if (window.navigator.msSaveOrOpenBlob) {
            navigator.msSaveOrOpenBlob(blob, dt.exportFilename + ".csv");
        }
        else {
            var link = document.createElement("a");
            link.style.display = "none";
            document.body.appendChild(link);
            if (link.download !== undefined) {
                link.setAttribute("href", URL.createObjectURL(blob));
                link.setAttribute("download", dt.exportFilename + ".csv");
                link.click();
            }
            else {
                csv = "data:text/csv;charset=utf-8," + csv;
                window.open(encodeURI(csv));
            }
            document.body.removeChild(link);
        }
    };
    BaseTableViewComponent.prototype.getDataTable = function () {
        return null;
    };
    BaseTableViewComponent.prototype.getColumna = function (record, field) {
        return null;
    };
    BaseTableViewComponent.prototype.getColumnaDominio = function (dominio, valor) {
        var domainMatch = dominio &&
            dominio.find(function (obj) {
                return obj.value == valor;
            });
        if (domainMatch) {
            return domainMatch.label;
        }
        else if (valor) {
            return String("??" + valor + "??");
        }
        return "";
    };
    BaseTableViewComponent.prototype.ngOnDestroy = function () {
        this.subscriptionMessages.unsubscribe();
    };
    BaseTableViewComponent.prototype.pageChanged = function (event) {
        console.log("pageChanged(" + event + ")");
        this.onPageChange.emit(event.page + 1);
    };
    /**
     * Método de ordenación de campos de fecha.
     * @see Adaptación de: https://stackoverflow.com/questions/41181277/primeng-datatable-custom-sorting-or-filtering-angular-2
     */
    BaseTableViewComponent.prototype.dateSort = function (event, field) {
        var comparer = function (a, b) {
            var formatedA = a[field] ? moment(a[field], "DD/MM/YYYY").format("YYYY-MM-DD") : "-";
            var formatedB = b[field] ? moment(b[field], "DD/MM/YYYY").format("YYYY-MM-DD") : "-";
            // let result = -1; if (moment(formatedB).isBefore(formatedA, 'day')) { result = 1; }
            var result = formatedA.localeCompare(formatedB);
            return result * event.order;
        };
        var strcmp = function (a, b) {
            if (a.toString() < b.toString()) {
                return -1;
            }
            if (a.toString() > b.toString()) {
                return 1;
            }
            return 0;
        };
        this.items.sort(comparer);
        this.items = this.items.slice();
    };
    __decorate([
        core_1.ViewChild("dataTable"),
        __metadata("design:type", datatable_1.DataTable)
    ], BaseTableViewComponent.prototype, "dataTable", void 0);
    __decorate([
        core_1.Input(),
        __metadata("design:type", Number)
    ], BaseTableViewComponent.prototype, "totalItems", void 0);
    __decorate([
        core_1.Output(),
        __metadata("design:type", Object)
    ], BaseTableViewComponent.prototype, "onPageChange", void 0);
    return BaseTableViewComponent;
}());
exports.BaseTableViewComponent = BaseTableViewComponent;
//# sourceMappingURL=base-tableview.component.js.map