"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var rxjs_1 = require("rxjs");
var operators_1 = require("rxjs/operators");
var base_service_1 = require("../../base/shared/base.service");
var http_utils_service_1 = require("../service/http-utils.service");
var message_service_1 = require("../service/message.service");
var domain_service_1 = require("../service/domain.service");
var session_shared_service_1 = require("../service/session-shared.service");
/**
 Servicio que devuelve los valores de un dominio ofrecidos por DomainService pero
 añadiendo un nivel de caché en sesión.

 De este modo, si N componentes quieren consumir el mismo servicio no provocaremos N llamadas REST.

 Esto lo hacemos solo con dominios ya que sabemos que no cambiarán durante el ciclo de vida de la aplicación.
 */
var DomainCachedService = /** @class */ (function (_super) {
    __extends(DomainCachedService, _super);
    function DomainCachedService(messageService, http, domainService, sessionShared) {
        var _this = _super.call(this, messageService, http) || this;
        _this.messageService = messageService;
        _this.http = http;
        _this.domainService = domainService;
        _this.sessionShared = sessionShared;
        _this.cachedResolvers = new Map();
        return _this;
    }
    DomainCachedService.prototype.getDominio = function (dominio) {
        var _this = this;
        // comprobamos si ya se ha pedido antes
        var replay = this.cachedResolvers.get(dominio);
        if (replay) {
            // ya tenemos preparado un ReplaySubject para ese dominio, lo devolvemos tal cual
            // si el valor todavía no ha llegado de servidor, cuando llegue se emitirá
            // si el valor ya había llegado de servidor, como es un replay=1 se emitirá inmediatamente
        }
        else {
            // es la primera vez que nos piden este dominio, así que hacemos lo siguiente
            // creamos un ReplaySubject que repetirá el último valor recibido cada vez que se subscriban a él
            // resolvemos el dominio contra servidor, y su resolución la emitimos contra el replaysubject
            replay = new rxjs_1.ReplaySubject(1); // solo repetiremos el último valor
            this.domainService.getDominio(dominio).subscribe(function (r) { replay.next(r); }, function (err) {
                // si ha fallado, nos libramos del replay para que el siguiente que lo pida vuelva a intentarlo
                replay.error(err);
                _this.cachedResolvers.delete(dominio);
            });
            this.cachedResolvers.set(dominio, replay);
        }
        // lo que devolvemos debe ser una copia, ya que si un componente manipula el objeto
        // el resto de componentes que usen el mismo dominio no deben enterarse
        return replay.pipe(operators_1.map(function (res) { return JSON.parse(JSON.stringify(res)); }));
    };
    DomainCachedService = __decorate([
        core_1.Injectable(),
        __metadata("design:paramtypes", [message_service_1.MessageService,
            http_utils_service_1.HttpUtilsService,
            domain_service_1.DomainService,
            session_shared_service_1.SessionSharedService])
    ], DomainCachedService);
    return DomainCachedService;
}(base_service_1.BaseCRUDService));
exports.DomainCachedService = DomainCachedService;
//# sourceMappingURL=domain-cached.service.js.map